import { flex } from "@/style-predefines";
import { css, useTheme } from "@emotion/react";
import styled from "@emotion/styled";
import { __, always, cond, includes, T } from "ramda";
import { PropsWithChildren } from "react";

type AvatarProps = {
  size?: "xs" | "sm" | "md" | "lg" | "xl" | "xxl";
  square?: boolean;
  bgColor?: string;
};

const AvatarContainer = styled("div")<AvatarProps>(({ theme, size, square }) => {
  const radiusSize = cond([
    [includes(__, ["xs", "sm", "md"]), always("xxs")],
    [T, always("xs")],
  ])(size);
  return css`
    height: ${theme.spacings[size]};
    width: ${theme.spacings[size]};
    border-radius: ${theme.radius[square ? "none" : radiusSize]};
    overflow: hidden;
    ${flex(theme, "row", "center", "center")}
    .child {
      overflow: hidden;
    }
  `;
});

export function Avatar({
  size = "md",
  square = false,
  bgColor,
  children,
}: PropsWithChildren<AvatarProps>) {
  const theme = useTheme();
  return (
    <AvatarContainer size={size} square={square}>
      <div className="child">{children}</div>
    </AvatarContainer>
  );
}
